util
============================================

Miscellaneous util functions native to scalecast.

metrics
----------
.. autoclass:: src.scalecast.util.metrics
   :members:

Forecaster_with_missing_vals()
-----------------------------------
.. autofunction:: src.scalecast.util.Forecaster_with_missing_vals

backtest_for_resid_matrix()
------------------------------
.. autofunction:: src.scalecast.util.backtest_for_resid_matrix

backtest_metrics()
-------------------------
.. autofunction:: src.scalecast.util.backtest_metrics

break_mv_forecaster()
-----------------------------
.. autofunction:: src.scalecast.util.break_mv_forecaster

find_optimal_coint_rank()
----------------------------
.. autofunction:: src.scalecast.util.find_optimal_coint_rank

find_optimal_lag_order()
---------------------------
.. autofunction:: src.scalecast.util.find_optimal_lag_order

find_optimal_transformation()
-----------------------------------
.. autofunction:: src.scalecast.util.find_optimal_transformation

find_statistical_transformation()
-----------------------------------
.. autofunction:: src.scalecast.util.find_statistical_transformation

get_backtest_resid_matrix()
-----------------------------------
.. autofunction:: src.scalecast.util.get_backtest_resid_matrix

overwrite_forecast_intervals()
-----------------------------------
.. autofunction:: src.scalecast.util.overwrite_forecast_intervals

plot_reduction_errors()
-----------------------------
.. autofunction:: src.scalecast.util.plot_reduction_errors
